@@ -1,12 +1,14 @@
+import os, shutil
+
 import responses
 from datetime import timedelta
 
 from freezegun import freeze_time
 
+from django.conf import settings as django_settings
 from django.test import override_settings
 from django.utils.timezone import now
 
-from germanium.decorators import data_consumer
 from germanium.test_cases.client import ClientTestCase
 from germanium.tools import (
     assert_equal, assert_false, assert_http_not_found, assert_http_ok, assert_http_redirect,
@@ -15,6 +17,7 @@ from germanium.tools import (
 )
 
 from security import requests
+from security.config import settings
 from security.backends.sql.models import CommandLog as SQLCommandLog
 from security.backends.elasticsearch.models import CommandLog as ElasticsearchCommandLog
 from security.backends.sql.models import CeleryTaskRunLog as SQLCeleryTaskRunLog
@@ -26,10 +29,6 @@ from security.backends.elasticsearch.models import InputRequestLog as Elasticsea
 from security.backends.sql.models import OutputRequestLog as SQLOutputRequestLog
 from security.backends.elasticsearch.models import OutputRequestLog as ElasticsearchOutputRequestLog
 
-from security.backends.signals import (
-    command_started, input_request_started, output_request_started, celery_task_invocation_started,
-    celery_task_run_started
-)
 from security.backends.testing import capture_security_logs
 
 from apps.test_security.tasks import sum_task
@@ -49,7 +48,11 @@ class CommandTestCase(BaseTestCaseMixin, ClientTestCase):
     }
 
     @responses.activate
-    @override_settings(SECURITY_BACKEND_WRITERS={'sql'}, SECURITY_COMMAND_LOG_EXCLUDED_COMMANDS={'purge_logs'})
+    @override_settings(
+        SECURITY_BACKEND_WRITERS={'sql'},
+        SECURITY_COMMAND_LOG_EXCLUDED_COMMANDS={'purge_logs'},
+        SECURITY_BACKUP_STORAGE_PATH=os.path.join(django_settings.PROJECT_DIR, 'var', 'backup_sql')
+    )
     def test_sql_purge_logs_should_remove_logged_data(self):
         responses.add(responses.GET, 'https://localhost/test', body='test')
 
@@ -67,19 +70,25 @@ class CommandTestCase(BaseTestCaseMixin, ClientTestCase):
         }
 
         for log_type, log_model in sql_type_model:
-            test_call_command('purge_logs', type=log_type, interactive=False, expiration='1d')
+            log_directory = os.path.join(settings.BACKUP_STORAGE_PATH, log_type)
+            os.makedirs(log_directory)
+            test_call_command('purge_logs', type=log_type, interactive=False, expiration='1d', backup=log_type)
             assert_equal(log_model.objects.count(), 1)
 
             with freeze_time(now() + timedelta(days=1, minutes=1)):
-                test_call_command('purge_logs', type=log_type, interactive=False, expiration='1d')
+                test_call_command('purge_logs', type=log_type, interactive=False, expiration='1d', backup=log_type)
                 assert_equal(log_model.objects.count(), 0)
+            assert_equal(len(os.listdir(log_directory)), 1)
+        shutil.rmtree(settings.BACKUP_STORAGE_PATH)
 
     @responses.activate
-    @override_settings(SECURITY_BACKEND_WRITERS={'elasticsearch'},
-                       SECURITY_COMMAND_LOG_EXCLUDED_COMMANDS={'purge_logs'})
+    @override_settings(
+        SECURITY_BACKEND_WRITERS={'elasticsearch'},
+        SECURITY_COMMAND_LOG_EXCLUDED_COMMANDS={'purge_logs'},
+        SECURITY_BACKUP_STORAGE_PATH=os.path.join(django_settings.PROJECT_DIR, 'var', 'backup_elastic')
+    )
     def test_elasticsearch_purge_logs_should_remove_logged_data(self):
         responses.add(responses.GET, 'https://localhost/test', body='test')
-
         with capture_security_logs() as logged_data:
             test_call_command('test_command')
             sum_task.apply(args=(5, 8))
@@ -95,15 +104,19 @@ class CommandTestCase(BaseTestCaseMixin, ClientTestCase):
             )
 
             for log_type, log_model, log_data_name in elasticsearch_type_model_receivers:
-                test_call_command('purge_logs', type=log_type, interactive=False, expiration='1d')
+                log_directory = os.path.join(settings.BACKUP_STORAGE_PATH, log_type)
+                os.makedirs(log_directory)
+                test_call_command('purge_logs', type=log_type, interactive=False, expiration='1d', backup=log_type)
                 log_model._index.refresh()
                 assert_equal(log_model.search().filter(
                     'ids', values=[logged_data[log_data_name][0].id]
                 ).count(), 1)
 
                 with freeze_time(now() + timedelta(days=1, minutes=1)):
-                    test_call_command('purge_logs', type=log_type, interactive=False, expiration='1d')
+                    test_call_command('purge_logs', type=log_type, interactive=False, expiration='1d', backup=log_type)
                     log_model._index.refresh()
                     assert_equal(log_model.search().filter(
                         'ids', values=[logged_data[log_data_name][0].id]
                     ).count(), 0)
+                assert_equal(len(os.listdir(log_directory)), 1)
+        shutil.rmtree(settings.BACKUP_STORAGE_PATH)
